@@ -167,7 +167,7 @@ def getWindowAnalyzeFileGivenText( fileName, gcodeText, repository=None):
 	"Display a gcode file in a skeinlayer window given the text."
 	if gcodeText == '':
 		return None
-	if repository is None:
+	if repository == None:
 		repository = settings.getReadRepository( SkeinlayerRepository() )
 	skeinWindow = getWindowGivenTextRepository( fileName, gcodeText, repository )
 	skeinWindow.updateDeiconify()
@@ -243,7 +243,7 @@ class SkeinlayerSkein:
 
 	def addToPath( self, line, location ):
 		"Add a point to travel and maybe extrusion."
-		if self.oldLocation is None:
+		if self.oldLocation == None:
 			return
 		colorName = 'gray'
 		locationComplex = location.dropAxis()
@@ -283,7 +283,7 @@ class SkeinlayerSkein:
 
 	def linearMove( self, line, location ):
 		"Get statistics for a linear move."
-		if self.skeinPane is not None:
+		if self.skeinPane != None:
 			self.addToPath(line, location)
 
 	def parseCorner(self, line):
@@ -463,6 +463,8 @@ class SkeinWindow( tableau.TableauWindow ):
 
 	def getColoredLines(self):
 		"Get the colored lines from the skein pane."
+		if len(self.skeinPanes) == 0:
+			return []
 		return self.skeinPanes[self.repository.layer.value]
 
 	def getCopy(self):
